@@ -1,5 +1,5 @@
 import os
-import minecraft_model_reader.api._log
+import logging
 from minecraft_model_reader.api.mesh.block.block_mesh import BlockMesh
 from minecraft_model_reader.api.resource_pack import (
     BaseResourcePack,
@@ -12,3 +12,6 @@ from ._version import get_versions
 
 __version__ = get_versions()["version"]
 del get_versions
+
+# init a default logger
+logging.basicConfig(level=logging.INFO, format="%(levelname)s - %(message)s")
