@@ -4,16 +4,19 @@ import zipfile
 import json
 from urllib.request import urlopen
 import io
-from typing import Generator
+from typing import Generator, List
+import logging
 
 import minecraft_model_reader
-from minecraft_model_reader import log
 from minecraft_model_reader.api.resource_pack import JavaResourcePack
 
+log = logging.getLogger(__name__)
+
 RESOURCE_PACK_DIR = os.path.join(
     minecraft_model_reader.path, "api", "resource_pack", "java", "resource_packs"
 )
 launcher_manifest = None
+INCLUDE_SNAPSHOT = False
 
 
 def get_launcher_manifest() -> dict:
@@ -49,7 +52,10 @@ def get_latest_iter() -> Generator[float, None, JavaResourcePack]:
     """
     vanilla_rp_path = os.path.join(RESOURCE_PACK_DIR, "java_vanilla")
     try:
-        new_version = get_launcher_manifest()["latest"]["release"]
+        if INCLUDE_SNAPSHOT:
+            new_version = get_launcher_manifest()["latest"]["snapshot"]
+        else:
+            new_version = get_launcher_manifest()["latest"]["release"]
     except Exception as e:
         if os.path.isdir(vanilla_rp_path):
             log.error(
@@ -62,7 +68,7 @@ def get_latest_iter() -> Generator[float, None, JavaResourcePack]:
         if os.path.isfile(os.path.join(vanilla_rp_path, "version")):
             with open(os.path.join(vanilla_rp_path, "version")) as f:
                 old_version = f.read()
-            has_new_pack = old_version != new_version
+            has_new_pack = old_version == new_version
 
         if not has_new_pack:
             yield from _remove_and_download_iter(vanilla_rp_path, new_version)
@@ -102,11 +108,26 @@ def _remove_and_download(path, version):
 
 
 def _remove_and_download_iter(path, version) -> Generator[float, None, None]:
-    if os.path.isdir(path):
-        shutil.rmtree(path, ignore_errors=True)
-    yield from download_resources_iter(path, version)
-    with open(os.path.join(path, "version"), "w") as f:
-        f.write(version)
+    # try downloading the new resources to a temporary location
+    temp_path = os.path.join(os.path.dirname(path), "_temp_")
+    # clear the temporary location
+    if os.path.isfile(temp_path):
+        os.remove(temp_path)
+    elif os.path.isdir(temp_path):
+        shutil.rmtree(temp_path, ignore_errors=True)
+
+    try:
+        yield from download_resources_iter(temp_path, version)
+    except:
+        pass
+    else:
+        if os.path.isdir(path):
+            shutil.rmtree(path, ignore_errors=True)
+
+        shutil.move(temp_path, path)
+
+        with open(os.path.join(path, "version"), "w") as f:
+            f.write(version)
 
 
 def download_resources(path, version):
@@ -141,14 +162,30 @@ def download_resources_iter(
                 yield min(1.0, (index * chunk_size) / (data_size * 2))
 
         client = zipfile.ZipFile(io.BytesIO(b"".join(data)))
-        paths = [fpath for fpath in client.namelist() if fpath.startswith("assets/")]
+        paths: List[str] = [
+            fpath for fpath in client.namelist() if fpath.startswith("assets/")
+        ]
         path_count = len(paths)
         for path_index, fpath in enumerate(paths):
             if not path_index % 30:
                 yield path_index / (path_count * 2) + 0.5
+            if fpath.endswith("/"):
+                continue
+            os.makedirs(
+                os.path.dirname(os.path.abspath(os.path.join(path, fpath))),
+                exist_ok=True,
+            )
             client.extract(fpath, path)
-        client.extract("pack.mcmeta", path)
-        client.extract("pack.png", path)
+        if "pack.mcmeta" in client.namelist():
+            client.extract("pack.mcmeta", path)
+        else:
+            # TODO: work out proper version support for this
+            with open(os.path.join(path, "pack.mcmeta"), "w") as f:
+                f.write(
+                    '{"pack": {"description": "The default data for Minecraft","pack_format": 7}}'
+                )
+        if "pack.png" in client.namelist():
+            client.extract("pack.png", path)
 
     except Exception as e:
         log.error(
